@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertCommandOutput;
 
-our $DATE = '2018-04-06'; # DATE
-our $VERSION = '0.050'; # VERSION
+our $DATE = '2019-02-04'; # DATE
+our $VERSION = '0.051'; # VERSION
 
 use 5.010001;
 use strict;
@@ -31,7 +31,8 @@ sub munge_file {
     my ($self, $file) = @_;
     my $content = $file->content;
     if ($content =~ s{^#\s*COMMAND:\s*(.*)\s*$}{$self->_command_output($1)."\n"}egm) {
-        $self->log(["inserting output of command '%s' in %s: '%s'", $1, $file->name, $content]);
+        $self->log(["inserting output of command '%s' in %s", $1, $file->name]);
+        $self->log_debug(["output of command: %s", $file->content]);
         $file->content($content);
     }
 }
@@ -65,7 +66,7 @@ Dist::Zilla::Plugin::InsertCommandOutput - Insert the output of command into you
 
 =head1 VERSION
 
-This document describes version 0.050 of Dist::Zilla::Plugin::InsertCommandOutput (from Perl distribution Dist-Zilla-Plugin-InsertCommandOutput), released on 2018-04-06.
+This document describes version 0.051 of Dist::Zilla::Plugin::InsertCommandOutput (from Perl distribution Dist-Zilla-Plugin-InsertCommandOutput), released on 2019-02-04.
 
 =head1 SYNOPSIS
 
@@ -120,7 +121,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
